@@ -9,10 +9,11 @@ from fractal import Fractal
 from fractal.contrib.fastapi.routers import Routes
 from fractal.contrib.fastapi.routers.domain.models import AdapterInfo, Info
 from fractal.contrib.fastapi.routers.tokens import get_payload, get_payload_roles
-from fractal.contrib.tokens.fractal import DummyTokenServiceFractal
+from fractal.contrib.tokens.fractal import DummyTokenRolesFractal
 from fractal.contrib.tokens.models import TokenPayload, TokenPayloadRoles
 from fractal.core.models import Model
 from fractal.core.services import Service
+from fractal.core.specifications.generic.specification import Specification
 from fractal.core.utils.application_context import ApplicationContext
 from fractal.core.utils.settings import Settings
 
@@ -33,7 +34,7 @@ def inject_default_routes(
     @router.get(Routes.INFO, responses={200: {"model": Info}})
     def info(
         payload: TokenPayload = Depends(
-            get_payload(DummyTokenServiceFractal(context, settings))
+            get_payload(DummyTokenRolesFractal(context, settings))
         ),
     ):
         adapters = list(context.adapters())
@@ -59,6 +60,8 @@ class DefaultRestRouterService(Service, ABC):
     domain_entity_class: Type[Model]
     entities_route: str
     entity_route: str
+    entities_endpoint: str
+    entity_endpoint: str
     entity_contract: Type[BaseModel]
     create_entity_contract: Type[BaseModel]
 
@@ -114,6 +117,8 @@ class BasicRestRouterService(DefaultRestRouterService):
     def add_entity(
         self,
         contract: Contract,
+        *,
+        specification: Specification = None,
         **kwargs,
     ):
         try:
@@ -123,29 +128,35 @@ class BasicRestRouterService(DefaultRestRouterService):
         _entity = contract.to_entity(
             user_id=kwargs.get("sub"), account_id=kwargs.get("account")
         )
-        return self.ingress_service.add(_entity, str(kwargs.get("sub")))
+        return self.ingress_service.add(_entity, str(kwargs.get("sub")), specification=specification)
 
     def find_entities(
         self,
         q: str = "",
+        *,
+        specification: Specification = None,
         **kwargs,
     ):
-        return self.ingress_service.find(str(kwargs.get("account")), q)
+        return self.ingress_service.find(str(kwargs.get("account")), q, specification=specification)
 
     def get_entity(
         self,
         entity_id: UUID,
+        *,
+        specification: Specification = None,
         **kwargs,
     ):
-        return self.ingress_service.get(str(entity_id), str(kwargs.get("account")))
+        return self.ingress_service.get(str(entity_id), str(kwargs.get("account")), specification=specification)
 
     def update_entity(
         self,
         entity_id: UUID,
         contract: Contract,
+        *,
+        specification: Specification = None,
         **kwargs,
     ):
-        if _entity := self.get_entity(entity_id, **kwargs):
+        if _entity := self.get_entity(entity_id, specification=specification, **kwargs):
             _entity = _entity.update(contract.dict())
         else:
             _entity = contract.to_entity(
@@ -154,16 +165,18 @@ class BasicRestRouterService(DefaultRestRouterService):
                 account_id=kwargs.get("account"),
             )
         return self.ingress_service.update(
-            str(entity_id), _entity, str(kwargs.get("sub"))
+            str(entity_id), _entity, str(kwargs.get("sub")), specification=specification
         )
 
     def delete_entity(
         self,
         entity_id: UUID,
+        *,
+        specification: Specification = None,
         **kwargs,
     ) -> Dict:
         self.ingress_service.delete(
-            str(entity_id), str(kwargs.get("sub")), str(kwargs.get("account"))
+            str(entity_id), str(kwargs.get("sub")), str(kwargs.get("account")), specification=specification
         )
         return {}
 
@@ -172,11 +185,7 @@ def inject_default_rest_routes(
     fractal: Fractal,
     *,
     router_service_class: Type[DefaultRestRouterService],
-    roles: Dict[str, List[str]] = None,
 ):
-    if roles is None:
-        roles = {}
-
     router = APIRouter()
 
     @router.post(
@@ -188,11 +197,16 @@ def inject_default_rest_routes(
     def add_entity(
         entity: router_service_class().create_entity_contract,
         payload: TokenPayloadRoles = Depends(
-            get_payload_roles(fractal, roles=roles.get("add", ["user"]))
+            get_payload_roles(
+                fractal,
+                endpoint=router_service_class().entities_endpoint,
+                method="post",
+            )
         ),
     ):
         return router_service_class().add_entity(
             contract=entity,
+            specification=payload.specification,
             **payload.dict(),
         )
 
@@ -205,11 +219,16 @@ def inject_default_rest_routes(
     def find_entities(
         q: Optional[str] = "",
         payload: TokenPayloadRoles = Depends(
-            get_payload_roles(fractal, roles=roles.get("get", ["user"]))
+            get_payload_roles(
+                fractal,
+                endpoint=router_service_class().entities_endpoint,
+                method="get",
+            )
         ),
     ):
         return router_service_class().find_entities(
             q=q,
+            specification=payload.specification,
             **payload.dict(),
         )
 
@@ -222,11 +241,16 @@ def inject_default_rest_routes(
     def get_entity(
         entity_id: UUID,
         payload: TokenPayloadRoles = Depends(
-            get_payload_roles(fractal, roles=roles.get("get", ["user"]))
+            get_payload_roles(
+                fractal,
+                endpoint=router_service_class().entities_endpoint,
+                method="get",
+            )
         ),
     ):
         return router_service_class().get_entity(
             entity_id=entity_id,
+            specification=payload.specification,
             **payload.dict(),
         )
 
@@ -240,12 +264,17 @@ def inject_default_rest_routes(
         entity_id: UUID,
         entity: router_service_class().entity_contract,
         payload: TokenPayloadRoles = Depends(
-            get_payload_roles(fractal, roles=roles.get("update", ["user"]))
+            get_payload_roles(
+                fractal,
+                endpoint=router_service_class().entities_endpoint,
+                method="put",
+            )
         ),
     ):
         return router_service_class().update_entity(
             entity_id=entity_id,
             contract=entity,
+            specification=payload.specification,
             **payload.dict(),
         )
 
@@ -258,11 +287,16 @@ def inject_default_rest_routes(
     def delete_entity(
         entity_id: UUID,
         payload: TokenPayloadRoles = Depends(
-            get_payload_roles(fractal, roles=roles.get("delete", ["user"]))
+            get_payload_roles(
+                fractal,
+                endpoint=router_service_class().entities_endpoint,
+                method="delete",
+            )
         ),
     ) -> Dict:
         return router_service_class().delete_entity(
             entity_id=entity_id,
+            specification=payload.specification,
             **payload.dict(),
         )
 
