@@ -1,5 +1,4 @@
 from dataclasses import asdict
-from datetime import date
 from typing import Iterator, Optional
 
 from google.cloud import firestore
@@ -106,10 +105,21 @@ class FirestoreRepositoryMixin(SettingsMixin, Repository[Entity]):
         return True
 
 
+# class FirestoreDict(dict):
+#     def __init__(self, obj):
+#         for i, v in enumerate(obj):
+#             if type(v[1]) is Decimal:
+#                 obj[i] = (v[0], f"{v[1]:.2f}")
+#             if type(v[1]) is date:
+#                 obj[i] = (v[0], v[1].isoformat())
+#         super(FirestoreDict, self).__init__(obj)
+
+
 class FirestoreRepositoryDictMixin(FirestoreRepositoryMixin[Entity]):
     def add(self, entity: Entity) -> Entity:
         doc_ref = self.collection.document(entity.id)
-        doc_ref.set(entity.asdict(skip_types=(date,)))
+        # doc_ref.set(asdict(entity, dict_factory=FirestoreDict))
+        doc_ref.set(entity.asdict())
         return entity
 
     def update(self, entity: Entity, *, upsert=False) -> Entity:
@@ -117,7 +127,8 @@ class FirestoreRepositoryDictMixin(FirestoreRepositoryMixin[Entity]):
             doc_ref = self.collection.document(entity.id)
             doc = doc_ref.get()
             if doc.exists:
-                doc_ref.set(entity.asdict(skip_types=(date,)))
+                # doc_ref.set(asdict(entity, dict_factory=FirestoreDict))
+                doc_ref.set(entity.asdict())
             return entity
         return self.add(entity)
 
